@@ -1,4 +1,5 @@
 import os
+import sys
 import unittest
 import django
 import django_settings
@@ -11,6 +12,9 @@ if __name__ == '__main__':
     os.environ['DJANGO_SETTINGS_MODULE'] = 'django_settings'
     django.setup()
     loader = unittest.TestLoader()
-    suite = loader.discover(TEST_DIR)
+    if len(sys.argv) > 1:
+        suite = loader.loadTestsFromName(sys.argv[1])
+    else:
+        suite = loader.discover(TEST_DIR)
     runner = unittest.TextTestRunner()
     runner.run(suite)
